@@ -5,15 +5,15 @@ use warnings;
 use bytes;
 require Exporter ;
 
-use IO::Compress::Base 2.023 ;
-use IO::Compress::Base::Common  2.023 qw(createSelfTiedObject);
+use IO::Compress::Base 2.024 ;
+use IO::Compress::Base::Common  2.024 qw(createSelfTiedObject);
 use IO::Compress::Adapter::Xz 2.020 ;
-use Compress::Raw::Lzma  2.023 ;
+use Compress::Raw::Lzma  2.024 ;
 
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $XzError);
 
-$VERSION = '2.023';
+$VERSION = '2.024';
 $XzError = '';
 
 @ISA    = qw(Exporter IO::Compress::Base);
@@ -53,8 +53,8 @@ sub getExtraParams
 {
     my $self = shift ;
 
-    use IO::Compress::Base::Common  2.023 qw(:Parse);
-    use Compress::Raw::Lzma 2.023 qw(LZMA_PRESET_DEFAULT LZMA_CHECK_CRC32) ;
+    use IO::Compress::Base::Common  2.024 qw(:Parse);
+    use Compress::Raw::Lzma 2.024 qw(LZMA_PRESET_DEFAULT LZMA_CHECK_CRC32) ;
     
     return (
         'Preset'        => [1, 1, Parse_unsigned, LZMA_PRESET_DEFAULT],
@@ -531,8 +531,16 @@ This parameter defaults to 0.
 
 =item C<< Preset => $preset >>
 
+Used to choose the compression preset.
+
 Valid values are 0-9 and C<LZMA_PRESET_DEFAULT>.
 
+0 is the fastest compression with the lowest memory usage and the lowest
+compression.
+
+9 is the slowest compession with the highest memory usage but with the best
+compression.
+
 Defaults to C<LZMA_PRESET_DEFAULT>.
 
 =item C<< Extreme => 0|1 >>
@@ -787,7 +795,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2009 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2010 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
